AdaptiveTextFieldBlocBuilder class

Uses CupertinoTextFieldBlocBuilder on iOS and TextFieldBlocBuilder everywhere else.

Inheritance

Constructors

AdaptiveTextFieldBlocBuilder({Key? key, required TextFieldBloc textFieldBloc, bool enableOnlyWhenFormBlocCanSubmit = false, bool isEnabled = true, FieldBlocErrorBuilder? errorBuilder, SuffixButton? suffixButton, EdgeInsetsGeometry? padding, FocusNode? focusNode, InputDecoration decoration = const InputDecoration(), TextInputType? keyboardType, TextInputAction? textInputAction, bool? obscureText, Iterable<String>? autofillHints, bool? sensitiveContent, int? maxLines = 1, bool readOnly = false, bool autofocus = false, FocusNode? nextFocusNode, bool animateWhenCanShow = true, bool focusOnValidationFailed = true, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), bool? forceCupertino, bool? forceMaterial})
const

Properties

animateWhenCanShow bool
final
autofillHints Iterable<String>?
final
autofocus bool
final
decoration InputDecoration
final
enableOnlyWhenFormBlocCanSubmit bool
final
errorBuilder FieldBlocErrorBuilder?
final
focusNode FocusNode?
final
focusOnValidationFailed bool
final
forceCupertino bool?
final
forceMaterial bool?
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
final
maxLines int?
final
nextFocusNode FocusNode?
final
obscureText bool?
final
onChanged ValueChanged<String>?
final
onSubmitted ValueChanged<String>?
final
padding EdgeInsetsGeometry?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding EdgeInsets
final
sensitiveContent bool?
final
suffixButton SuffixButton?
final
textFieldBloc TextFieldBloc
final
textInputAction TextInputAction?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited