CupertinoTextFieldBlocBuilder class
An iOS-style text field integrated with TextFieldBloc.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CupertinoTextFieldBlocBuilder
Constructors
-
CupertinoTextFieldBlocBuilder({Key? key, required TextFieldBloc textFieldBloc, bool enableOnlyWhenFormBlocCanSubmit = false, bool isEnabled = true, FieldBlocErrorBuilder? errorBuilder, EdgeInsetsGeometry? padding, FocusNode? focusNode, InputDecoration decoration = const InputDecoration(), TextInputType keyboardType = TextInputType.text, TextInputAction? textInputAction, bool? obscureText, Iterable<
String> ? autofillHints, bool? sensitiveContent, int? maxLines = 1, int? minLines, bool readOnly = false, bool autofocus = false, FocusNode? nextFocusNode, bool animateWhenCanShow = true, bool focusOnValidationFailed = true, bool showObscureToggle = true, ValueChanged<String> ? onChanged, ValueChanged<String> ? onSubmitted, EdgeInsets scrollPadding = const EdgeInsets.all(20.0)}) -
const
Properties
- animateWhenCanShow → bool
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- decoration → InputDecoration
-
final
- enableOnlyWhenFormBlocCanSubmit → bool
-
final
- errorBuilder → FieldBlocErrorBuilder?
-
final
- focusNode → FocusNode?
-
final
- focusOnValidationFailed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- nextFocusNode → FocusNode?
-
final
- obscureText → bool?
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
-
onSubmitted
→ ValueChanged<
String> ? -
final
- padding → EdgeInsetsGeometry?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPadding → EdgeInsets
-
final
- sensitiveContent → bool?
-
final
- showObscureToggle → bool
-
final
- textFieldBloc → TextFieldBloc
-
final
- textInputAction → TextInputAction?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CupertinoTextFieldBlocBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited