clearError abstract method
void
clearError()
Clears the validation error without changing the field value.
Similar to Flutter's FormFieldState.clearError.
Implementation
void clearError();
Clears the validation error without changing the field value.
Similar to Flutter's FormFieldState.clearError.
void clearError();