StepperFormBlocBuilder<T extends FormBloc> class
Constructors
-
StepperFormBlocBuilder({Key? key, T? formBloc, required List<FormBlocStep> stepsBuilder(T? formBloc), ScrollPhysics? physics, StepperType type = StepperType.vertical, bool showTitle = true, bool animateStepTransitions = true, void onStepTapped(FormBloc? formBloc, int step)?, void onStepContinue(FormBloc? formBloc)?, void onStepCancel(FormBloc? formBloc)?, Widget controlsBuilder(BuildContext context, VoidCallback? onStepContinue, VoidCallback? onStepCancel, int step, FormBloc formBloc)?})
-
const
Properties
-
animateStepTransitions
→ bool
-
When
false, step content transitions are instant. Also respects the
platform MediaQuery.disableAnimations setting.
final
-
controlsBuilder
→ Widget Function(BuildContext context, VoidCallback? onStepContinue, VoidCallback? onStepCancel, int step, FormBloc formBloc)?
-
The callback for creating custom controls.
final
-
formBloc
→ T?
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onStepCancel
→ void Function(FormBloc? formBloc)?
-
The callback called when the 'cancel' button is tapped.
final
-
onStepContinue
→ void Function(FormBloc? formBloc)?
-
The callback called when the 'continue' button is tapped.
final
-
onStepTapped
→ void Function(FormBloc? formBloc, int step)?
-
The callback called when a step is tapped, with its index passed as
an argument.
final
-
physics
→ ScrollPhysics?
-
How the stepper's scroll view should respond to user input.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
showTitle
→ bool
-
final
-
stepsBuilder
→ List<FormBlocStep> Function(T? formBloc)
-
The steps of the stepper whose titles, subtitles, icons always get shown.
final
-
type
→ StepperType
-
The type of stepper that determines the layout. In the case of
StepperType.horizontal, the content of the current step is displayed
underneath as opposed to the StepperType.vertical case where it is
displayed in-between.
final